pub struct PathElement<E, M>{
pub point: Coord,
pub edge: Edge<Node<E>>,
pub metadata: M,
}Expand description
An element within a path, consisting of the [Point] the element represents within the path, as well as metadata (Meta) for the path element, and the edge within the source network at which the element exists.
Fields
point: Coordedge: Edge<Node<E>>metadata: MImplementations