pub struct WeightAndDistance(pub Fraction, pub u32);Expand description
Represents a thin structure storing the weight and distance associated with a candidate
Tuple Fields
0: Fraction1: u32Implementations
Sourceimpl WeightAndDistance
impl WeightAndDistance
Sourcepub fn repr(&self) -> u32
pub fn repr(&self) -> u32
A representation method which allows distinguishment between structures
on a given f(weight, distance) = weight² × distance function,
returning a u32 representation of the structure.
Using a quadratic road-class weighting ensures that the Dijkstra path finder strongly penalises lower-quality roads (e.g. offramps / MotorwayLink), preventing short detours through lower-class roads from being preferred over longer, same-class routes.
With quadratic weighting a MotorwayLink detour (weight=2) has an effective cost 4× that of an equal-length motorway segment (weight=1), so the direct motorway is preferred unless the detour is less than one quarter of the motorway path length.
pub const fn new(frac: Fraction, weight: u32) -> Self